@@ -44,3 +44,23 @@ class MachineChangeTypeException(RcException):
 
 class MachineNotReadyException(RcException):
     pass
+
+
+class SaveImageException(RcException):
+    pass
+
+
+class DeleteImageException(RcException):
+    pass
+
+
+class FirewallRuleCreationException(RcException):
+    pass
+
+
+class FirewallRuleDeleteionException(RcException):
+    pass
+
+
+class PmapException(RcException):
+    pass
